%1-30-2008 Raj Chetty
%This file calculates effect of variations in policies (e.g. UI benefit level) on welfare and search intensity
%Output is simulation data used to draw Figure 2

%psi(s) = theta*[s^(1+sigma)]/(1+sigma)
%psi'(s)=theta*s^sigma
%u(c) = [c^(1-gamma)]/(1-gamma)
%v(c) = [c^(1-gamma)]/(1-gamma)
%delta=0, r=0

clear all

w=340
T=500
L=-1000
a=0;
A0=100
G=0;
G_T = T;

theta = 5
sigma = .1
gamma = 1.75

B=26

rr_inc = .03
rr_inc_der = .02
reprate = [.05:.015:.2 .21:.03:.96]
b=reprate*w;

toler=0.1
gridsize =400
tau_init=0.03*reprate(1)*w

tic

%1 Exact calculation

for i = 1:length(A0) 
    for j = 1:length(b)
    disp(['Exact Calc.: Current reprate is ' num2str(reprate(j))])
    [D_star, D_comp_star, S_0_star, J_0_star, tau_bb] = budget_balance(A0(i),L,G,G_T,w,a,b(j),tau_init,T,B,gridsize,toler,theta,sigma,gamma);
    D(j,i) = D_star;
    s_0(j,i) = S_0_star;
    J_0(j,i) = J_0_star;
    tax_pct(j,i)=tau_bb/w;
    tau_init=tau_bb;

    %calculate dJ0/dw
    [D_winc, D_comp_winc, S_0_winc, J_0_winc, tau_winc] = budget_balance(A0(i),L,G,G_T,w+rr_inc_der*w,a,b(j),tau_init,T,B,gridsize,toler,theta,sigma,gamma)
    dJ_dw(j,i) = (J_0_winc-J_0_star)/(rr_inc_der*w);
    
    %calculate dJ0/db
    [D_binc, D_comp_binc, S_0_binc, J_0_binc, tau_binc] = budget_balance(A0(i),L,G,G_T,w,a,b(j)+rr_inc_der*w,tau_init,T,B,gridsize,toler,theta,sigma,gamma);
    dJ_db(j,i) = (J_0_binc-J_0_star)/(rr_inc_der*w);
    e_db_tot(j,i) = (log(D_binc)-log(D_star))/(log(b(j)+rr_inc_der*w)-log(b(j)));    
    e_db_tot_comp(j,i) = (log(D_comp_binc)-log(D_comp_star))/(log(b(j)+rr_inc_der*w)-log(b(j)));    
end    
end

dW_db_exact = dJ_db./dJ_dw;
sig_exact = (T-D)./T;

%2 Approximate calculation

for i = 1:length(A0) 
    for j = 1:length(b)
    disp(['Approx Calc.: Current reprate is ' num2str(reprate(j))])
    tau = tax_pct(j,i)*w;
    [D_star, D_comp_star, S_0_star, J_0_star, rho_adj_fac_star, liq_mh_a_star, liq_mh_A_star] = opt_search_polfn_crra(A0(i),L,G,G_T,w,a,b(j),tau,T,B,gridsize,theta,sigma,gamma)
    D(j,i) = D_star;
    D_comp(j,i) = D_comp_star;
    s_0(j,i) = S_0_star;
    J_0(j,i) = J_0_star;
    rho_adj_fac(j,i) = rho_adj_fac_star;
    liq_mh_a_an(j,i) = liq_mh_a_star;
    liq_mh_A_an(j,i) = liq_mh_A_star;
    
    %calculate ds/da
    [D_ainc, D_comp_ainc, S_0_ainc, J_0_ainc] = opt_search_polfn_crra(A0(i),L,G,G_T,w,a+rr_inc_der*w,b(j),tau,T,B,gridsize,theta,sigma,gamma);
    ds_da(j,i) = (S_0_ainc-S_0_star)/(rr_inc_der*w);

    %calculate ds/dA
    Ainc=B*rr_inc_der*w;
    [D_Ainc, D_comp_Ainc, S_0_Ainc, J_0_Ainc] = opt_search_polfn_crra(A0(i)+Ainc,L,G,G_T,w,a,b(j),tau,T,B,gridsize,theta,sigma,gamma);
    ds_dA(j,i) = (S_0_Ainc-S_0_star)/Ainc;

    %calculate ds/db and e_db (partial der, so this is an approximation)
    [D_binc, D_comp_binc, S_0_binc, J_0_binc] = opt_search_polfn_crra(A0(i),L,G,G_T,w,a,b(j)+rr_inc_der*w,tau,T,B,gridsize,theta,sigma,gamma);
    ds_db(j,i) = (S_0_binc-S_0_star)/(rr_inc_der*w);
    e_db(j,i) = (log(D_binc)-log(D_star))/(log(b(j)+rr_inc_der*w)-log(b(j)));    
    e_db_comp(j,i) = (log(D_comp_binc)-log(D_comp_star))/(log(b(j)+rr_inc_der*w)-log(b(j)));    

end
end

toc

sig = (T-D)./T;
liq_mh_a = -ds_da./(ds_da-ds_db);
liq_mh_A = -B*ds_dA./(B*ds_dA-ds_db);
D_ratio = D_comp./D;

dW_db_approx_a = ((1-sig)./sig).*D_ratio.*(liq_mh_a-e_db_comp./sig);
dW_db_approx_A = ((1-sig)./sig).*D_ratio.*(liq_mh_A-e_db_comp./sig);
dW_db_approx_a_an = ((1-sig)./sig).*D_ratio.*(liq_mh_a_an-e_db_comp./sig);
dW_db_approx_A_an = ((1-sig)./sig).*D_ratio.*(liq_mh_A_an-e_db_comp./sig);

%3 Construct Data

disp('reprate dW_db_exact dW_db_approx_a dW_db_approx_A dW_db_approx_a_an dW_db_approx_A_an e_db e_db_comp D D_comp sig liq_mh_a liq_mh_A rho_adj_fac')
data_wcomp = [reprate' dW_db_exact dW_db_approx_a dW_db_approx_A dW_db_approx_a_an dW_db_approx_A_an e_db e_db_comp D D_comp sig liq_mh_a liq_mh_A rho_adj_fac]

save fig2_data_wcomp_final data_wcomp
